<?php

/**
 * WooCommerce compatibility and custom functions
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 * @return void
 */
function instock_lite_wc_setup() {
    add_theme_support('woocommerce', apply_filters('instock_lite_wc_args', array(
        'product_grid'          => array(
            'default_columns' => 3,
            'default_rows'    => 4,
            'min_columns'     => 1,
            'max_columns'     => 6,
            'min_rows'        => 1
        )
    )));
    add_theme_support('wc-product-gallery-zoom');
    add_theme_support('wc-product-gallery-lightbox');
    add_theme_support('wc-product-gallery-slider');
}
add_action('after_setup_theme', 'instock_lite_wc_setup');

/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
function instock_lite_wc_scripts() {

    $theme_version = wp_get_theme()->get('Version');
    wp_enqueue_style('instock-lite-woocommerce-style', get_template_directory_uri() . '/woocommerce.css', array(), $theme_version);

    $font_path   = esc_url(WC()->plugin_url() . '/assets/fonts/');
    $inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				url("' . $font_path . 'star.woff") format("woff"),
				url("' . $font_path . 'star.ttf") format("truetype"),
				url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: normal;
			font-style: normal;
		}';

    wp_add_inline_style('instock-woocommerce-style', $inline_font);
}
add_action('wp_enqueue_scripts', 'instock_lite_wc_scripts');

/**
 * Disable the default WooCommerce stylesheet.
 *
 * Removing the default WooCommerce stylesheet and enqueing your own will
 * protect you during WooCommerce core updates.
 *
 * @link https://docs.woocommerce.com/document/disable-the-default-stylesheet/
 */
add_filter('woocommerce_enqueue_styles', '__return_empty_array');

/**
 * Remove WooCommerce breadcrumbs.
 */
remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);

/**
 * Remove WooCommerce shop title.
 */
add_filter('woocommerce_show_page_title', '__return_false');

/**
 * Remove add to cart button
 */
remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart');

/**
 * Quick view integration
 */
add_filter('woosq_button_position', function () {
    return '0';
});

/**
 * Smart compare integration
 */
add_filter('filter_wooscp_button_archive', function () {
    return '0';
});
add_filter('filter_wooscp_button_single', function () {
    return '0';
});

/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function instock_lite_wc_active_body_class($classes) {
    $classes[] = 'woocommerce-active';

    return $classes;
}
add_filter('body_class', 'instock_lite_wc_active_body_class');

/**
 * Full width layout for cart and checkout page.
 */
function instock_lite_wc_page_layout($class) {

    if (is_cart() || is_checkout()) {
        $class = 'full-width';
    }

    if (is_shop() || is_product_category() || is_product_tag()) {
        $layout = get_theme_mod('shop_layout', 'right-sidebar');
        $class = sanitize_html_class($layout);
    }

    return $class;
}
add_filter('instock_lite_post_layout_class', 'instock_lite_wc_page_layout', 10);

/**
 * Default loop columns on product archives.
 *
 * @return integer products per row.
 */
function instock_lite_wc_loop_columns() {
    return 3;
}
add_filter('loop_shop_columns', 'instock_lite_wc_loop_columns');

/**
 * Related Products Args.
 *
 * @param array $args related products args.
 * @return array $args related products args.
 */
function instock_lite_wc_related_products_args($args) {
    $defaults = array(
        'posts_per_page' => 3,
        'columns'        => 3,
    );

    $args = wp_parse_args($defaults, $args);

    return $args;
}
add_filter('woocommerce_output_related_products_args', 'instock_lite_wc_related_products_args');
add_filter('woocommerce_upsell_display_args', 'instock_lite_wc_related_products_args');

if (!function_exists('instock_lite_wc_product_columns_wrapper')) {
    /**
     * Product columns wrapper.
     *
     * @return  void
     */
    function instock_lite_wc_product_columns_wrapper() {
        $columns = instock_lite_wc_loop_columns();
        echo '<div class="products-wrapper columns-' . absint($columns) . '">';
    }
}
add_action('woocommerce_before_shop_loop', 'instock_lite_wc_product_columns_wrapper', 40);

if (!function_exists('instock_lite_wc_product_columns_wrapper_close')) {
    /**
     * Product columns wrapper close.
     *
     * @return  void
     */
    function instock_lite_wc_product_columns_wrapper_close() {
        echo '</div>';
    }
}
add_action('woocommerce_after_shop_loop', 'instock_lite_wc_product_columns_wrapper_close', 40);

/**
 * Remove default WooCommerce wrapper.
 */
remove_action('woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action('woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

if (!function_exists('instock_lite_wc_wrapper_before')) {
    /**
     * Before Content.
     *
     * Wraps all WooCommerce content in wrappers which match the theme markup.
     *
     * @return void
     */
    function instock_lite_wc_wrapper_before() {
?>
        <div class="container">
            <div id="primary" class="content-area">
                <main id="main" class="site-main">
                <?php
            }
        }
        add_action('woocommerce_before_main_content', 'instock_lite_wc_wrapper_before');

        if (!function_exists('instock_lite_wc_wrapper_after')) {
            /**
             * After Content.
             *
             * Closes the wrapping divs.
             *
             * @return void
             */
            function instock_lite_wc_wrapper_after() {
                ?>
                </main><!-- #main -->
            </div><!-- #primary -->
        <?php
            }
        }
        add_action('woocommerce_after_main_content', 'instock_lite_wc_wrapper_after');

        if (!function_exists('instock_lite_wc_after_sidebar')) {
            /**
             * After Sidebar.
             *
             * Closes the container div.
             *
             * @return void
             */
            function instock_lite_wc_after_sidebar() {
        ?>
        </div><!-- .container -->
    <?php
            }
        }
        add_action('woocommerce_sidebar', 'instock_lite_wc_after_sidebar');

        /**
         * Sample implementation of the WooCommerce Mini Cart.
         *
         * You can add the WooCommerce Mini Cart to header.php like so ...
         *
	<?php
		if ( function_exists( 'instock_lite_wc_header_cart' ) ) {
			instock_lite_wc_header_cart();
		}
	?>
         */

        if (!function_exists('instock_lite_wc_cart_link_fragment')) {
            /**
             * Cart Fragments.
             *
             * Ensure cart contents update when products are added to the cart via AJAX.
             *
             * @param array $fragments Fragments to refresh via AJAX.
             * @return array Fragments to refresh via AJAX.
             */
            function instock_lite_wc_cart_link_fragment($fragments) {
                ob_start();
                instock_lite_wc_cart_link();
                $fragments['a.cart-contents'] = ob_get_clean();

                return $fragments;
            }
        }
        add_filter('woocommerce_add_to_cart_fragments', 'instock_lite_wc_cart_link_fragment');

        if (!function_exists('instock_lite_wc_cart_link')) {
            /**
             * Cart Link.
             *
             * Displayed a link to the cart including the number of items present and the cart total.
             *
             * @return void
             */
            function instock_lite_wc_cart_link() {
    ?>
        <a class="cart-contents" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e('View your shopping cart', 'instock-lite'); ?>">
            <span class="count"><?php echo wp_kses_data(WC()->cart->get_cart_contents_count()); ?></span>
            <?php esc_html_e('Cart', 'instock-lite'); ?>
        </a>
    <?php
            }
        }

        if (!function_exists('instock_lite_wc_header_cart')) {
            /**
             * Display Header Cart.
             *
             * @return void
             */
            function instock_lite_wc_header_cart() {
    ?>
        <ul id="site-header-cart" class="site-header-cart">
            <li>
                <?php instock_lite_wc_cart_link(); ?>
            </li>
            <li>
                <?php
                $instance = array(
                    'title' => '',
                );

                the_widget('WC_Widget_Cart', $instance);
                ?>
            </li>
        </ul>
    <?php
            }
        }

        if (!function_exists('instock_lite_wc_toolbar_wrapper_before')) {
            /**
             * Before toolbar.
             *
             * Wraps products toolbar WooCommerce content.
             *
             * @return void
             */
            function instock_lite_wc_toolbar_wrapper_before() {
    ?>
        <div class="wc-toolbar">
        <?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'instock_lite_wc_toolbar_wrapper_before', 9);

        if (!function_exists('instock_lite_wc_toolbar_wrapper_after')) {
            /**
             * After toolbar.
             *
             * Closes the products toolbar wrapping divs.
             *
             * @return void
             */
            function instock_lite_wc_toolbar_wrapper_after() {
        ?>
        </div><!-- .wc-toolbar -->
    <?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'instock_lite_wc_toolbar_wrapper_after', 35);

        if (!function_exists('instock_lite_wc_toolbar_left_wrapper_before')) {
            /**
             * Before toolbar left.
             *
             * Wraps products toolbar WooCommerce content.
             *
             * @return void
             */
            function instock_lite_wc_toolbar_left_wrapper_before() {
    ?>
        <div class="wc-toolbar-left">
        <?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'instock_lite_wc_toolbar_left_wrapper_before', 19);

        if (!function_exists('instock_lite_wc_toolbar_left_wrapper_after')) {
            /**
             * After toolbar left.
             *
             * Wraps products toolbar WooCommerce content.
             *
             * @return void
             */
            function instock_lite_wc_toolbar_left_wrapper_after() {
        ?>
        </div><!-- .wc-toolbar-left -->
    <?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'instock_lite_wc_toolbar_left_wrapper_after', 22);

        if (!function_exists('instock_lite_wc_toolbar_right_wrapper_before')) {
            /**
             * Before toolbar right.
             *
             * Wraps products toolbar WooCommerce content.
             *
             * @return void
             */
            function instock_lite_wc_toolbar_right_wrapper_before() {
    ?>
        <div class="wc-toolbar-right">
        <?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'instock_lite_wc_toolbar_right_wrapper_before', 29);

        if (!function_exists('instock_lite_wc_toolbar_right_wrapper_after')) {
            /**
             * After toolbar right.
             *
             * Wraps products toolbar WooCommerce content.
             *
             * @return void
             */
            function instock_lite_wc_toolbar_right_wrapper_after() {
        ?>
        </div><!-- .wc-toolbar-right -->
    <?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'instock_lite_wc_toolbar_right_wrapper_after', 32);

        /**
         * Products per page
         */
        function instock_lite_products_per_page() {
            $num_prod = (isset($_GET['products-per-page'])) ? $_GET['products-per-page'] : apply_filters('instock_lite_products_per_page', 12);

            if ($num_prod == 'all') {
                $num_prod = wp_count_posts('product')->publish;
            }

            return $num_prod;
        }
        add_filter('loop_shop_per_page', 'instock_lite_products_per_page');

        /**
         * Remove default product thumbnail
         */
        remove_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);

        if (!function_exists('instock_lite_product_thumbnail')) {
            /**
             * Catalog thumbnail swap
             */
            function instock_lite_product_thumbnail() {
                if (function_exists('wc_get_template')) {
                    wc_get_template('image-swap.php');
                }
            }
        }
        add_action('woocommerce_before_shop_loop_item_title', 'instock_lite_product_thumbnail', 10);

        /**
         * Change close link position
         */
        remove_action('woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5);
        add_action('woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 11);

        if (!function_exists('instock_lite_wc_thumbnail_wrapper_before')) {
            /**
             * Wrap image and custom buttons.
             */
            function instock_lite_wc_thumbnail_wrapper_before() {
    ?>
        <div class="wc-product-image">
        <?php
            }
        }
        add_action('woocommerce_before_shop_loop_item', 'instock_lite_wc_thumbnail_wrapper_before', 9);

        if (!function_exists('instock_lite_wc_thumbnail_wrapper_after')) {
            /**
             * Close wrap image and custom buttons.
             */
            function instock_lite_wc_thumbnail_wrapper_after() {
        ?>
        </div>
    <?php
            }
        }
        add_action('woocommerce_before_shop_loop_item_title', 'instock_lite_wc_thumbnail_wrapper_after', 12);

        if (!function_exists('instock_lite_wc_details_wrapper_before')) {
            /**
             * Wrap product details.
             */
            function instock_lite_wc_details_wrapper_before() {
    ?>
        <div class="wc-product-details">
        <?php
            }
        }
        add_action('woocommerce_shop_loop_item_title', 'instock_lite_wc_details_wrapper_before', 9);

        if (!function_exists('instock_lite_wc_details_wrapper_after')) {
            /**
             * Close wrap product details.
             */
            function instock_lite_wc_details_wrapper_after() {
        ?>
        </div>
    <?php
            }
        }
        add_action('woocommerce_after_shop_loop_item', 'instock_lite_wc_details_wrapper_after', 11);

        /**
         * Remove title
         */
        remove_action('woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title', 10);

        if (!function_exists('instock_lite_wc_product_title')) {
            /**
             * Product title with link
             */
            function instock_lite_wc_product_title() {
    ?>
        <a href="<?php the_permalink(); ?>"><?php woocommerce_template_loop_product_title(); ?></a>
<?php
            }
        }
        add_action('woocommerce_shop_loop_item_title', 'instock_lite_wc_product_title', 10);

        /**
         * Change rating position in single product
         */
        remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10);
        add_action('woocommerce_single_product_summary', 'woocommerce_template_single_rating', 4);

        if (!function_exists('instock_lite_before_order_review')) :
            /**
             * Checkout page before order review
             *
             * @since   1.0.0
             */
            function instock_lite_before_order_review() {
                echo '<div class="review-order-wrapper">';
            }
        endif;
        add_action('woocommerce_checkout_after_customer_details', 'instock_lite_before_order_review', 10);

        if (!function_exists('instock_lite_after_order_review')) :
            /**
             * Checkout page after order review
             *
             * @since   1.0.0
             */
            function instock_lite_after_order_review() {
                echo '</div>';
            }
        endif;
        add_action('woocommerce_checkout_after_order_review', 'instock_lite_after_order_review', 10);

        if (!function_exists('instock_lite_wc_account_link')) :
            /**
             * My account link
             */
            function instock_lite_wc_account_link() {

                echo '<span class="wc-account-link">';
                if (is_user_logged_in()) {
                    echo '<a href="' . esc_url(get_permalink(get_option('woocommerce_myaccount_page_id'))) . '" title="' . esc_attr__('My Account', 'instock-lite') . '">' . esc_html__('My Account', 'instock-lite') . '</a>';
                } else {
                    echo '<a href="' . esc_url(get_permalink(get_option('woocommerce_myaccount_page_id'))) . '" title="' . esc_attr__('Login / Register', 'instock-lite') . '">' . esc_html__('Login', 'instock-lite') . '</a>';
                }
                echo '</span>';
            }
        endif;
